pitchtools.permute_named_chromatic_pitch_carrier_list_by_twelve_tone_row
========================================================================

.. autofunction:: abjad.tools.pitchtools.permute_named_chromatic_pitch_carrier_list_by_twelve_tone_row.permute_named_chromatic_pitch_carrier_list_by_twelve_tone_row
